<?php

/**
 * @file
 * Menu callback for leaflet_maptiler admin configuration.
 */

/**
 * Displays the Attachment Settings Form.
 */
function leaflet_maptiler_settings_form() {
  /*
   * Initialize form with empty array.
   */
  $form = array();
  /*
   * Adds field for the Maptiler API Key.
   */
  $form['leaflet_maptiler_api_key'] = array(
    '#type' => 'textfield',
    '#size' => 60,
    '#maxlength' => 255,
    '#required' => TRUE,
    '#default_value' => variable_get('leaflet_maptiler_api_key', ''),
    '#title' => t('Maptiler API Key'),
    '#description' => t('Enter API Key for Maptiler.'),
  );
  /*
   * Adds field for setting the Maptiler layers to use.
   */
  $form['leaflet_maptiler_layers'] = array(
    '#type' => 'textfield',
    '#title' => t('Maptiler Layers'),
    '#size' => 22,
    '#description' => t('Insert the name of the Maptiler Layers in small letters and separated by comma (example: basic, bright, hybrid, etc.)'),
    '#default_value' => variable_get('leaflet_maptiler_layers', ''),
  );
  /*
   * Adds fieldset for the geocoder external library settings.
   */
  $form['leaflet_maptiler_geocode_fieldset'] = array(
    '#type' => 'fieldset',
    '#title' => t('Geocoder external library'),
    '#tree' => TRUE,
  );
  /*
   * Adds field for setting the Geocoder js library url.
   */
  $form['leaflet_maptiler_geocode_fieldset']['leaflet_maptiler_geocoder_js'] = array(
    '#type' => 'textfield',
    '#title' => t('Geocoder JS library url'),
    '#size' => 60,
    '#maxlength' => 255,
    '#default_value' => variable_get('leaflet_maptiler_geocoder_js', '//unpkg.com/leaflet-control-geocoder/dist/Control.Geocoder.js'),
  );
  /*
   * Adds field for setting the Geocoder css library url.
   */
  $form['leaflet_maptiler_geocode_fieldset']['leaflet_maptiler_geocoder_css'] = array(
    '#type' => 'textfield',
    '#title' => t('Geocoder css library url'),
    '#size' => 60,
    '#maxlength' => 255,
    '#default_value' => variable_get('leaflet_maptiler_geocoder_css', '//unpkg.com/leaflet-control-geocoder/dist/Control.Geocoder.css'),
  );
  /*
   * Sets up a form to save information automatically.
   */
  $form = system_settings_form($form);
  /*
   * Adds an extra submit callback in order to
   * clear cache when the form is saved.
   */
  $form['#submit'][] = 'leaflet_maptiler_settings_form_submit';
  return $form;
}

/**
 * Form submission handler for leaflet_maptiler_settings_form().
 *
 * It clears all cache after saving the form values or
 * hook_leaflet_more_maps() won't be called.
 *
 * @param array $form
 *   An associative array containing the structure of the form.
 * @param array $form_state
 *   A keyed array containing the current state of the form.
 */
function leaflet_maptiler_settings_form_submit($form, &$form_state) {
  cache_clear_all('*', 'cache', TRUE);
}
