<?php

/**
 * @file
 * Builds placeholder replacement maptiler tokens.
 */

/**
 * Implements hook_token_info().
 */
function leaflet_maptiler_token_token_info() {
  /*
   * Sets the token group type.
   */
  $type = array(
    'name' => t('Maptiler Token'),
    'description' => t('Token for showing a map based on Maptiler API.'),
  );
  /*
   * Sets the latitude, longitude, zoom and height token.
   */
  $tokens['lat_lng_zoom_height'] = array(
    'name' => t('Maptiler latitude, longitude, zoom and height token'),
    'description' => t('Maptiler token that renders a map based on latitude, longitude, zoom and height arguments.'),
  );

  return array(
    'types' => array('maptiler' => $type),
    'tokens' => array('maptiler' => $tokens),
  );
}

/**
 * Implements hook_tokens().
 */
function leaflet_maptiler_token_tokens($type, $tokens, array $data = array(), array $options = array()) {
  $replacements = array();

  if ($type == 'maptiler') {
    /*
     * Process each maptiler token.
     */
    foreach ($tokens as $name => $original) {
      /*
       * Extracts token name.
       */
      $exploded_name = explode(':', $name);
      /*
       * If the token has arguments.
       */
      if (count($exploded_name) > 1) {
        switch ($exploded_name[0]) {
          case 'lat_lng_zoom_height':
            $exploded_coord = explode('+', $exploded_name[1]);

            if (count($exploded_coord) > 1) {
              /*
               * Generate Point based on longitude and latitude.
               */
              $coord = geofield_compute_values(array('lat' => $exploded_coord[0], 'lon' => $exploded_coord[1]), GEOFIELD_INPUT_LAT_LON);
              /*
               * Process coordinates.
               */
              $points = leaflet_process_geofield(array($coord));
              /*
               * Gets the Maptiler map info.
               */
              $map = leaflet_map_get_info('Maptiler');
              /*
               * If Maptiler map exists.
               */
              if (!empty($map)) {
                /*
                 * Adds the zoom settings based on token arguments.
                 */
                if (!empty($exploded_coord[2]) && ctype_digit($exploded_coord[2])) {
                  $map["settings"]["zoomDefault"] = (int) $exploded_coord[2];
                }
                if (!empty($exploded_coord[3]) && ctype_digit($exploded_coord[3])) {
                  /*
                   * Renders the map as a replacement with custom height.
                   */
                  $replacements[$original] = leaflet_render_map($map, array($points[0]), $exploded_coord[3] . 'px');
                }
                else {
                  /*
                   * Renders the map as a replacement with default height.
                   */
                  $replacements[$original] = leaflet_render_map($map, array($points[0]));
                }
              }
            }
            break;
        }
      }
    }
  }
  return $replacements;
}
